@@ -3,7 +3,11 @@
 ;; Copyright (C) 1999 by Free Software Foundation, Inc.
 
 ;; Author: SHIMADA Mitsunobu <simm-emacs@fan.gr.jp>
-;; Keywords: MULE, XEmacs, Meadow, UTF-2000, Genji, FLIM, SEMI, Rail
+;;         Youhei SASAKI <uwabami@gfd-dennou.org>
+;; Version: 1.2.12
+;; Package-Requires: ((emacs "25")(semi "14"))
+;; Keywords: MULE, Genji, FLIM, SEMI, Rail
+;; URL: https://github.com/uwabami/rail
 
 ;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -26,47 +30,30 @@
 
 ;;; Code:
 
-(require 'rail-vars)
-
-(cond ((featurep 'xemacs)
-       (require 'rail-xmas))
-      ((featurep 'mule)
-       (require 'rail-mule)))
+(require 'rail-common)
+(eval-when-compile
+  (require 'mime-setup))
 
 ;; Replace ISO-8859-1 character into ISO-8859-4
-(and rail-user-agent-replace-into-iso8859-4
-     (fboundp 'eval-after-load)
-     (eval-after-load "mime-def"
-       '(aset mime-library-product 2
-	      (rail-replace-into-iso8859-4 (aref mime-library-product 2)))))
-(and rail-user-agent-replace-into-iso8859-4
-     (fboundp 'eval-after-load)
-     (eval-after-load "semi-def"
-       '(aset mime-user-interface-product 2
-	      (rail-replace-into-iso8859-4 (aref mime-user-interface-product 2)))))
-
+(when rail-user-agent-replace-into-iso8859-4
+  (with-eval-after-load "mime-def"
+    '(aset mime-library-product 2
+           (rail-replace-into-iso8859-4 (aref mime-library-product 2)))))
+(when rail-user-agent-replace-into-iso8859-4
+  (with-eval-after-load "semi-def"
+    '(aset mime-user-interface-product 2
+           (rail-replace-into-iso8859-4 (aref mime-user-interface-product 2)))))
+;; Update mule version
+(when rail-emulate-genjis
+  (setq mule-version (rail-replace-codename mule-version nil
+                                            rail-additional-mule-codename-alist
+                                            rail-mule-codename-alist)))
 ;; load rail-user-agent.el
 (if (featurep 'semi-def)
     (load "rail-user-agent")
   (add-hook 'mime-setup-load-hook
-	    '(lambda () (load "rail-user-agent"))))
-
-;; load rail-mime-example-1-13.el for SEMI-1.13.*
-(and (fboundp 'eval-after-load)
-     (eval-after-load "mime-play"
-       (progn
-	 (load "rail-mime-example-1-13")
-	 '(rail-mime-example-1-13-setup))))
-
-;; load rail-mime-example-1-14.el for SEMI-1.14.*
-(and (fboundp 'eval-after-load)
-     (eval-after-load "mime-view"
-       (progn
-	 (load "rail-mime-example-1-14")
-	 '(rail-mime-example-1-14-setup))))
-
-;; for irchat-pj
-(require 'rail-pj)
+            (lambda ()
+              (load "rail-user-agent"))))
 
 ;; That's all
 (provide 'rail)
